==> kubernetes-model-autoscaling-5.11.2-sources.jar: io/fabric8/kubernetes/api/model/autoscaling/v2beta2/ObjectMetricStatusFluentImpl.java <==
package io.fabric8.kubernetes.api.model.autoscaling.v2beta2;

import io.fabric8.kubernetes.api.builder.Nested;
import java.lang.String;
import java.util.LinkedHashMap;
import java.lang.Deprecated;
import io.fabric8.kubernetes.api.builder.BaseFluent;
import java.lang.Boolean;
import java.lang.Object;
import java.util.Map;

 /**
  * Generated
  */
public class ObjectMetricStatusFluentImpl<A extends io.fabric8.kubernetes.api.model.autoscaling.v2beta2.ObjectMetricStatusFluent<A>> extends io.fabric8.kubernetes.api.builder.BaseFluent<A> implements io.fabric8.kubernetes.api.model.autoscaling.v2beta2.ObjectMetricStatusFluent<A>{
  public ObjectMetricStatusFluentImpl() {
  }
  public ObjectMetricStatusFluentImpl(io.fabric8.kubernetes.api.model.autoscaling.v2beta2.ObjectMetricStatus instance) {
    this.withCurrent(instance.getCurrent()); 
    this.withDescribedObject(instance.getDescribedObject()); 
    this.withMetric(instance.getMetric()); 
    this.withAdditionalProperties(instance.getAdditionalProperties());

  }
  private io.fabric8.kubernetes.api.model.autoscaling.v2beta2.MetricValueStatusBuilder current;
  private io.fabric8.kubernetes.api.model.autoscaling.v2beta2.CrossVersionObjectReferenceBuilder describedObject;
  private io.fabric8.kubernetes.api.model.autoscaling.v2beta2.MetricIdentifierBuilder metric;
  private java.util.Map<java.lang.String,java.lang.Object> additionalProperties;
  
  /**
   * This method has been deprecated, please use method buildCurrent instead.
   * @return The buildable object.
   */
  @java.lang.Deprecated
  public io.fabric8.kubernetes.api.model.autoscaling.v2beta2.MetricValueStatus getCurrent() {
    return this.current!=null?this.current.build():null;
  }
  public io.fabric8.kubernetes.api.model.autoscaling.v2beta2.MetricValueStatus buildCurrent() {
    return this.current!=null?this.current.build():null;
  }
  public A withCurrent(io.fabric8.kubernetes.api.model.autoscaling.v2beta2.MetricValueStatus current) {
    _visitables.get("current").remove(this.current);
    if (current!=null){ this.current= new io.fabric8.kubernetes.api.model.autoscaling.v2beta2.MetricValueStatusBuilder(current); _visitables.get("current").add(this.current);} return (A) this;
  }
  public java.lang.Boolean hasCurrent() {
    return this.current != null;
  }
  public io.fabric8.kubernetes.api.model.autoscaling.v2beta2.ObjectMetricStatusFluent.CurrentNested<A> withNewCurrent() {
    return new io.fabric8.kubernetes.api.model.autoscaling.v2beta2.ObjectMetricStatusFluentImpl.CurrentNestedImpl();
  }
  public io.fabric8.kubernetes.api.model.autoscaling.v2beta2.ObjectMetricStatusFluent.CurrentNested<A> withNewCurrentLike(io.fabric8.kubernetes.api.model.autoscaling.v2beta2.MetricValueStatus item) {
    return new io.fabric8.kubernetes.api.model.autoscaling.v2beta2.ObjectMetricStatusFluentImpl.CurrentNestedImpl(item);
  }
  public io.fabric8.kubernetes.api.model.autoscaling.v2beta2.ObjectMetricStatusFluent.CurrentNested<A> editCurrent() {
    return withNewCurrentLike(getCurrent());
  }
  public io.fabric8.kubernetes.api.model.autoscaling.v2beta2.ObjectMetricStatusFluent.CurrentNested<A> editOrNewCurrent() {
    return withNewCurrentLike(getCurrent() != null ? getCurrent(): new io.fabric8.kubernetes.api.model.autoscaling.v2beta2.MetricValueStatusBuilder().build());
  }
  public io.fabric8.kubernetes.api.model.autoscaling.v2beta2.ObjectMetricStatusFluent.CurrentNested<A> editOrNewCurrentLike(io.fabric8.kubernetes.api.model.autoscaling.v2beta2.MetricValueStatus item) {
    return withNewCurrentLike(getCurrent() != null ? getCurrent(): item);
  }
  
  /**
   * This method has been deprecated, please use method buildDescribedObject instead.
   * @return The buildable object.
   */
  @java.lang.Deprecated
  public io.fabric8.kubernetes.api.model.autoscaling.v2beta2.CrossVersionObjectReference getDescribedObject() {
    return this.describedObject!=null?this.describedObject.build():null;
  }
  public io.fabric8.kubernetes.api.model.autoscaling.v2beta2.CrossVersionObjectReference buildDescribedObject() {
    return this.describedObject!=null?this.describedObject.build():null;
  }
  public A withDescribedObject(io.fabric8.kubernetes.api.model.autoscaling.v2beta2.CrossVersionObjectReference describedObject) {
    _visitables.get("describedObject").remove(this.describedObject);
    if (describedObject!=null){ this.describedObject= new io.fabric8.kubernetes.api.model.autoscaling.v2beta2.CrossVersionObjectReferenceBuilder(describedObject); _visitables.get("describedObject").add(this.describedObject);} return (A) this;
  }
  public java.lang.Boolean hasDescribedObject() {
    return this.describedObject != null;
  }
  public A withNewDescribedObject(java.lang.String apiVersion,java.lang.String kind,java.lang.String name) {
    return (A)withDescribedObject(new CrossVersionObjectReference(apiVersion, kind, name));
  }
  public io.fabric8.kubernetes.api.model.autoscaling.v2beta2.ObjectMetricStatusFluent.DescribedObjectNested<A> withNewDescribedObject() {
    return new io.fabric8.kubernetes.api.model.autoscaling.v2beta2.ObjectMetricStatusFluentImpl.DescribedObjectNestedImpl();
  }
  public io.fabric8.kubernetes.api.model.autoscaling.v2beta2.ObjectMetricStatusFluent.DescribedObjectNested<A> withNewDescribedObjectLike(io.fabric8.kubernetes.api.model.autoscaling.v2beta2.CrossVersionObjectReference item) {
    return new io.fabric8.kubernetes.api.model.autoscaling.v2beta2.ObjectMetricStatusFluentImpl.DescribedObjectNestedImpl(item);
  }
  public io.fabric8.kubernetes.api.model.autoscaling.v2beta2.ObjectMetricStatusFluent.DescribedObjectNested<A> editDescribedObject() {
    return withNewDescribedObjectLike(getDescribedObject());
  }
  public io.fabric8.kubernetes.api.model.autoscaling.v2beta2.ObjectMetricStatusFluent.DescribedObjectNested<A> editOrNewDescribedObject() {
    return withNewDescribedObjectLike(getDescribedObject() != null ? getDescribedObject(): new io.fabric8.kubernetes.api.model.autoscaling.v2beta2.CrossVersionObjectReferenceBuilder().build());
  }
  public io.fabric8.kubernetes.api.model.autoscaling.v2beta2.ObjectMetricStatusFluent.DescribedObjectNested<A> editOrNewDescribedObjectLike(io.fabric8.kubernetes.api.model.autoscaling.v2beta2.CrossVersionObjectReference item) {
    return withNewDescribedObjectLike(getDescribedObject() != null ? getDescribedObject(): item);
  }
  
  /**
   * This method has been deprecated, please use method buildMetric instead.
   * @return The buildable object.
   */
  @java.lang.Deprecated
  public io.fabric8.kubernetes.api.model.autoscaling.v2beta2.MetricIdentifier getMetric() {
    return this.metric!=null?this.metric.build():null;
  }
  public io.fabric8.kubernetes.api.model.autoscaling.v2beta2.MetricIdentifier buildMetric() {
    return this.metric!=null?this.metric.build():null;
  }
  public A withMetric(io.fabric8.kubernetes.api.model.autoscaling.v2beta2.MetricIdentifier metric) {
    _visitables.get("metric").remove(this.metric);
    if (metric!=null){ this.metric= new io.fabric8.kubernetes.api.model.autoscaling.v2beta2.MetricIdentifierBuilder(metric); _visitables.get("metric").add(this.metric);} return (A) this;
  }
  public java.lang.Boolean hasMetric() {
    return this.metric != null;
  }
  public io.fabric8.kubernetes.api.model.autoscaling.v2beta2.ObjectMetricStatusFluent.MetricNested<A> withNewMetric() {
    return new io.fabric8.kubernetes.api.model.autoscaling.v2beta2.ObjectMetricStatusFluentImpl.MetricNestedImpl();
  }
  public io.fabric8.kubernetes.api.model.autoscaling.v2beta2.ObjectMetricStatusFluent.MetricNested<A> withNewMetricLike(io.fabric8.kubernetes.api.model.autoscaling.v2beta2.MetricIdentifier item) {
    return new io.fabric8.kubernetes.api.model.autoscaling.v2beta2.ObjectMetricStatusFluentImpl.MetricNestedImpl(item);
  }
  public io.fabric8.kubernetes.api.model.autoscaling.v2beta2.ObjectMetricStatusFluent.MetricNested<A> editMetric() {
    return withNewMetricLike(getMetric());
  }
  public io.fabric8.kubernetes.api.model.autoscaling.v2beta2.ObjectMetricStatusFluent.MetricNested<A> editOrNewMetric() {
    return withNewMetricLike(getMetric() != null ? getMetric(): new io.fabric8.kubernetes.api.model.autoscaling.v2beta2.MetricIdentifierBuilder().build());
  }
  public io.fabric8.kubernetes.api.model.autoscaling.v2beta2.ObjectMetricStatusFluent.MetricNested<A> editOrNewMetricLike(io.fabric8.kubernetes.api.model.autoscaling.v2beta2.MetricIdentifier item) {
    return withNewMetricLike(getMetric() != null ? getMetric(): item);
  }
  public A addToAdditionalProperties(java.lang.String key,java.lang.Object value) {
    if(this.additionalProperties == null && key != null && value != null) { this.additionalProperties = new java.util.LinkedHashMap<java.lang.String,java.lang.Object>(); }
    if(key != null && value != null) {this.additionalProperties.put(key, value);} return (A)this;
  }
  public A addToAdditionalProperties(java.util.Map<java.lang.String,java.lang.Object> map) {
    if(this.additionalProperties == null && map != null) { this.additionalProperties = new java.util.LinkedHashMap<java.lang.String,java.lang.Object>(); }
    if(map != null) { this.additionalProperties.putAll(map);} return (A)this;
  }
  public A removeFromAdditionalProperties(java.lang.String key) {
    if(this.additionalProperties == null) { return (A) this; }
    if(key != null && this.additionalProperties != null) {this.additionalProperties.remove(key);} return (A)this;
  }
  public A removeFromAdditionalProperties(java.util.Map<java.lang.String,java.lang.Object> map) {
    if(this.additionalProperties == null) { return (A) this; }
    if(map != null) { for(Object key : map.keySet()) {if (this.additionalProperties != null){this.additionalProperties.remove(key);}}} return (A)this;
  }
  public java.util.Map<java.lang.String,java.lang.Object> getAdditionalProperties() {
    return this.additionalProperties;
  }
  public <K,V>A withAdditionalProperties(java.util.Map<java.lang.String,java.lang.Object> additionalProperties) {
    if (additionalProperties == null) { this.additionalProperties =  null;} else {this.additionalProperties = new java.util.LinkedHashMap<java.lang.String,java.lang.Object>(additionalProperties);} return (A) this;
  }
  public java.lang.Boolean hasAdditionalProperties() {
    return this.additionalProperties != null;
  }
  public boolean equals(java.lang.Object o) {
    if (this == o) return true;
    if (o == null || getClass() != o.getClass()) return false;
    ObjectMetricStatusFluentImpl that = (ObjectMetricStatusFluentImpl) o;
    if (current != null ? !current.equals(that.current) :that.current != null) return false;
    if (describedObject != null ? !describedObject.equals(that.describedObject) :that.describedObject != null) return false;
    if (metric != null ? !metric.equals(that.metric) :that.metric != null) return false;
    if (additionalProperties != null ? !additionalProperties.equals(that.additionalProperties) :that.additionalProperties != null) return false;
    return true;
  }
  public int hashCode() {
    return java.util.Objects.hash(current,  describedObject,  metric,  additionalProperties,  super.hashCode());
  }
  public class CurrentNestedImpl<N> extends io.fabric8.kubernetes.api.model.autoscaling.v2beta2.MetricValueStatusFluentImpl<io.fabric8.kubernetes.api.model.autoscaling.v2beta2.ObjectMetricStatusFluent.CurrentNested<N>> implements io.fabric8.kubernetes.api.model.autoscaling.v2beta2.ObjectMetricStatusFluent.CurrentNested<N>,io.fabric8.kubernetes.api.builder.Nested<N>{
    CurrentNestedImpl(io.fabric8.kubernetes.api.model.autoscaling.v2beta2.MetricValueStatus item) {
      this.builder = new io.fabric8.kubernetes.api.model.autoscaling.v2beta2.MetricValueStatusBuilder(this, item);
    }
    CurrentNestedImpl() {
      this.builder = new io.fabric8.kubernetes.api.model.autoscaling.v2beta2.MetricValueStatusBuilder(this);
    }
    io.fabric8.kubernetes.api.model.autoscaling.v2beta2.MetricValueStatusBuilder builder;
    public N and() {
      return (N) ObjectMetricStatusFluentImpl.this.withCurrent(builder.build());
    }
    public N endCurrent() {
      return and();
    }
    
  }
  public class DescribedObjectNestedImpl<N> extends io.fabric8.kubernetes.api.model.autoscaling.v2beta2.CrossVersionObjectReferenceFluentImpl<io.fabric8.kubernetes.api.model.autoscaling.v2beta2.ObjectMetricStatusFluent.DescribedObjectNested<N>> implements io.fabric8.kubernetes.api.model.autoscaling.v2beta2.ObjectMetricStatusFluent.DescribedObjectNested<N>,io.fabric8.kubernetes.api.builder.Nested<N>{
    DescribedObjectNestedImpl(io.fabric8.kubernetes.api.model.autoscaling.v2beta2.CrossVersionObjectReference item) {
      this.builder = new io.fabric8.kubernetes.api.model.autoscaling.v2beta2.CrossVersionObjectReferenceBuilder(this, item);
    }
    DescribedObjectNestedImpl() {
      this.builder = new io.fabric8.kubernetes.api.model.autoscaling.v2beta2.CrossVersionObjectReferenceBuilder(this);
    }
    io.fabric8.kubernetes.api.model.autoscaling.v2beta2.CrossVersionObjectReferenceBuilder builder;
    public N and() {
      return (N) ObjectMetricStatusFluentImpl.this.withDescribedObject(builder.build());
    }
    public N endDescribedObject() {
      return and();
    }
    
  }
  public class MetricNestedImpl<N> extends io.fabric8.kubernetes.api.model.autoscaling.v2beta2.MetricIdentifierFluentImpl<io.fabric8.kubernetes.api.model.autoscaling.v2beta2.ObjectMetricStatusFluent.MetricNested<N>> implements io.fabric8.kubernetes.api.model.autoscaling.v2beta2.ObjectMetricStatusFluent.MetricNested<N>,io.fabric8.kubernetes.api.builder.Nested<N>{
    MetricNestedImpl(io.fabric8.kubernetes.api.model.autoscaling.v2beta2.MetricIdentifier item) {
      this.builder = new io.fabric8.kubernetes.api.model.autoscaling.v2beta2.MetricIdentifierBuilder(this, item);
    }
    MetricNestedImpl() {
      this.builder = new io.fabric8.kubernetes.api.model.autoscaling.v2beta2.MetricIdentifierBuilder(this);
    }
    io.fabric8.kubernetes.api.model.autoscaling.v2beta2.MetricIdentifierBuilder builder;
    public N and() {
      return (N) ObjectMetricStatusFluentImpl.this.withMetric(builder.build());
    }
    public N endMetric() {
      return and();
    }
    
  }
  
}

==> kubernetes-model-autoscaling-5.12.0-sources.jar: io/fabric8/kubernetes/api/model/autoscaling/v2beta2/ObjectMetricStatusFluentImpl.java <==
package io.fabric8.kubernetes.api.model.autoscaling.v2beta2;

import io.fabric8.kubernetes.api.builder.Nested;
import java.lang.String;
import java.util.LinkedHashMap;
import java.lang.Deprecated;
import io.fabric8.kubernetes.api.builder.BaseFluent;
import java.lang.Boolean;
import java.lang.Object;
import java.util.Map;

 /**
  * Generated
  */
public class ObjectMetricStatusFluentImpl<A extends io.fabric8.kubernetes.api.model.autoscaling.v2beta2.ObjectMetricStatusFluent<A>> extends io.fabric8.kubernetes.api.builder.BaseFluent<A> implements io.fabric8.kubernetes.api.model.autoscaling.v2beta2.ObjectMetricStatusFluent<A>{
  public ObjectMetricStatusFluentImpl() {
  }
  public ObjectMetricStatusFluentImpl(io.fabric8.kubernetes.api.model.autoscaling.v2beta2.ObjectMetricStatus instance) {
    this.withCurrent(instance.getCurrent()); 
    this.withDescribedObject(instance.getDescribedObject()); 
    this.withMetric(instance.getMetric()); 
    this.withAdditionalProperties(instance.getAdditionalProperties());

  }
  private io.fabric8.kubernetes.api.model.autoscaling.v2beta2.MetricValueStatusBuilder current;
  private io.fabric8.kubernetes.api.model.autoscaling.v2beta2.CrossVersionObjectReferenceBuilder describedObject;
  private io.fabric8.kubernetes.api.model.autoscaling.v2beta2.MetricIdentifierBuilder metric;
  private java.util.Map<java.lang.String,java.lang.Object> additionalProperties;
  
  /**
   * This method has been deprecated, please use method buildCurrent instead.
   * @return The buildable object.
   */
  @java.lang.Deprecated
  public io.fabric8.kubernetes.api.model.autoscaling.v2beta2.MetricValueStatus getCurrent() {
    return this.current!=null?this.current.build():null;
  }
  public io.fabric8.kubernetes.api.model.autoscaling.v2beta2.MetricValueStatus buildCurrent() {
    return this.current!=null?this.current.build():null;
  }
  public A withCurrent(io.fabric8.kubernetes.api.model.autoscaling.v2beta2.MetricValueStatus current) {
    _visitables.get("current").remove(this.current);
    if (current!=null){ this.current= new io.fabric8.kubernetes.api.model.autoscaling.v2beta2.MetricValueStatusBuilder(current); _visitables.get("current").add(this.current);} return (A) this;
  }
  public java.lang.Boolean hasCurrent() {
    return this.current != null;
  }
  public io.fabric8.kubernetes.api.model.autoscaling.v2beta2.ObjectMetricStatusFluent.CurrentNested<A> withNewCurrent() {
    return new io.fabric8.kubernetes.api.model.autoscaling.v2beta2.ObjectMetricStatusFluentImpl.CurrentNestedImpl();
  }
  public io.fabric8.kubernetes.api.model.autoscaling.v2beta2.ObjectMetricStatusFluent.CurrentNested<A> withNewCurrentLike(io.fabric8.kubernetes.api.model.autoscaling.v2beta2.MetricValueStatus item) {
    return new io.fabric8.kubernetes.api.model.autoscaling.v2beta2.ObjectMetricStatusFluentImpl.CurrentNestedImpl(item);
  }
  public io.fabric8.kubernetes.api.model.autoscaling.v2beta2.ObjectMetricStatusFluent.CurrentNested<A> editCurrent() {
    return withNewCurrentLike(getCurrent());
  }
  public io.fabric8.kubernetes.api.model.autoscaling.v2beta2.ObjectMetricStatusFluent.CurrentNested<A> editOrNewCurrent() {
    return withNewCurrentLike(getCurrent() != null ? getCurrent(): new io.fabric8.kubernetes.api.model.autoscaling.v2beta2.MetricValueStatusBuilder().build());
  }
  public io.fabric8.kubernetes.api.model.autoscaling.v2beta2.ObjectMetricStatusFluent.CurrentNested<A> editOrNewCurrentLike(io.fabric8.kubernetes.api.model.autoscaling.v2beta2.MetricValueStatus item) {
    return withNewCurrentLike(getCurrent() != null ? getCurrent(): item);
  }
  
  /**
   * This method has been deprecated, please use method buildDescribedObject instead.
   * @return The buildable object.
   */
  @java.lang.Deprecated
  public io.fabric8.kubernetes.api.model.autoscaling.v2beta2.CrossVersionObjectReference getDescribedObject() {
    return this.describedObject!=null?this.describedObject.build():null;
  }
  public io.fabric8.kubernetes.api.model.autoscaling.v2beta2.CrossVersionObjectReference buildDescribedObject() {
    return this.describedObject!=null?this.describedObject.build():null;
  }
  public A withDescribedObject(io.fabric8.kubernetes.api.model.autoscaling.v2beta2.CrossVersionObjectReference describedObject) {
    _visitables.get("describedObject").remove(this.describedObject);
    if (describedObject!=null){ this.describedObject= new io.fabric8.kubernetes.api.model.autoscaling.v2beta2.CrossVersionObjectReferenceBuilder(describedObject); _visitables.get("describedObject").add(this.describedObject);} return (A) this;
  }
  public java.lang.Boolean hasDescribedObject() {
    return this.describedObject != null;
  }
  public A withNewDescribedObject(java.lang.String apiVersion,java.lang.String kind,java.lang.String name) {
    return (A)withDescribedObject(new CrossVersionObjectReference(apiVersion, kind, name));
  }
  public io.fabric8.kubernetes.api.model.autoscaling.v2beta2.ObjectMetricStatusFluent.DescribedObjectNested<A> withNewDescribedObject() {
    return new io.fabric8.kubernetes.api.model.autoscaling.v2beta2.ObjectMetricStatusFluentImpl.DescribedObjectNestedImpl();
  }
  public io.fabric8.kubernetes.api.model.autoscaling.v2beta2.ObjectMetricStatusFluent.DescribedObjectNested<A> withNewDescribedObjectLike(io.fabric8.kubernetes.api.model.autoscaling.v2beta2.CrossVersionObjectReference item) {
    return new io.fabric8.kubernetes.api.model.autoscaling.v2beta2.ObjectMetricStatusFluentImpl.DescribedObjectNestedImpl(item);
  }
  public io.fabric8.kubernetes.api.model.autoscaling.v2beta2.ObjectMetricStatusFluent.DescribedObjectNested<A> editDescribedObject() {
    return withNewDescribedObjectLike(getDescribedObject());
  }
  public io.fabric8.kubernetes.api.model.autoscaling.v2beta2.ObjectMetricStatusFluent.DescribedObjectNested<A> editOrNewDescribedObject() {
    return withNewDescribedObjectLike(getDescribedObject() != null ? getDescribedObject(): new io.fabric8.kubernetes.api.model.autoscaling.v2beta2.CrossVersionObjectReferenceBuilder().build());
  }
  public io.fabric8.kubernetes.api.model.autoscaling.v2beta2.ObjectMetricStatusFluent.DescribedObjectNested<A> editOrNewDescribedObjectLike(io.fabric8.kubernetes.api.model.autoscaling.v2beta2.CrossVersionObjectReference item) {
    return withNewDescribedObjectLike(getDescribedObject() != null ? getDescribedObject(): item);
  }
  
  /**
   * This method has been deprecated, please use method buildMetric instead.
   * @return The buildable object.
   */
  @java.lang.Deprecated
  public io.fabric8.kubernetes.api.model.autoscaling.v2beta2.MetricIdentifier getMetric() {
    return this.metric!=null?this.metric.build():null;
  }
  public io.fabric8.kubernetes.api.model.autoscaling.v2beta2.MetricIdentifier buildMetric() {
    return this.metric!=null?this.metric.build():null;
  }
  public A withMetric(io.fabric8.kubernetes.api.model.autoscaling.v2beta2.MetricIdentifier metric) {
    _visitables.get("metric").remove(this.metric);
    if (metric!=null){ this.metric= new io.fabric8.kubernetes.api.model.autoscaling.v2beta2.MetricIdentifierBuilder(metric); _visitables.get("metric").add(this.metric);} return (A) this;
  }
  public java.lang.Boolean hasMetric() {
    return this.metric != null;
  }
  public io.fabric8.kubernetes.api.model.autoscaling.v2beta2.ObjectMetricStatusFluent.MetricNested<A> withNewMetric() {
    return new io.fabric8.kubernetes.api.model.autoscaling.v2beta2.ObjectMetricStatusFluentImpl.MetricNestedImpl();
  }
  public io.fabric8.kubernetes.api.model.autoscaling.v2beta2.ObjectMetricStatusFluent.MetricNested<A> withNewMetricLike(io.fabric8.kubernetes.api.model.autoscaling.v2beta2.MetricIdentifier item) {
    return new io.fabric8.kubernetes.api.model.autoscaling.v2beta2.ObjectMetricStatusFluentImpl.MetricNestedImpl(item);
  }
  public io.fabric8.kubernetes.api.model.autoscaling.v2beta2.ObjectMetricStatusFluent.MetricNested<A> editMetric() {
    return withNewMetricLike(getMetric());
  }
  public io.fabric8.kubernetes.api.model.autoscaling.v2beta2.ObjectMetricStatusFluent.MetricNested<A> editOrNewMetric() {
    return withNewMetricLike(getMetric() != null ? getMetric(): new io.fabric8.kubernetes.api.model.autoscaling.v2beta2.MetricIdentifierBuilder().build());
  }
  public io.fabric8.kubernetes.api.model.autoscaling.v2beta2.ObjectMetricStatusFluent.MetricNested<A> editOrNewMetricLike(io.fabric8.kubernetes.api.model.autoscaling.v2beta2.MetricIdentifier item) {
    return withNewMetricLike(getMetric() != null ? getMetric(): item);
  }
  public A addToAdditionalProperties(java.lang.String key,java.lang.Object value) {
    if(this.additionalProperties == null && key != null && value != null) { this.additionalProperties = new java.util.LinkedHashMap(); }
    if(key != null && value != null) {this.additionalProperties.put(key, value);} return (A)this;
  }
  public A addToAdditionalProperties(java.util.Map<java.lang.String,java.lang.Object> map) {
    if(this.additionalProperties == null && map != null) { this.additionalProperties = new java.util.LinkedHashMap(); }
    if(map != null) { this.additionalProperties.putAll(map);} return (A)this;
  }
  public A removeFromAdditionalProperties(java.lang.String key) {
    if(this.additionalProperties == null) { return (A) this; }
    if(key != null && this.additionalProperties != null) {this.additionalProperties.remove(key);} return (A)this;
  }
  public A removeFromAdditionalProperties(java.util.Map<java.lang.String,java.lang.Object> map) {
    if(this.additionalProperties == null) { return (A) this; }
    if(map != null) { for(Object key : map.keySet()) {if (this.additionalProperties != null){this.additionalProperties.remove(key);}}} return (A)this;
  }
  public java.util.Map<java.lang.String,java.lang.Object> getAdditionalProperties() {
    return this.additionalProperties;
  }
  public <K,V>A withAdditionalProperties(java.util.Map<java.lang.String,java.lang.Object> additionalProperties) {
    if (additionalProperties == null) { this.additionalProperties =  null;} else {this.additionalProperties = new java.util.LinkedHashMap(additionalProperties);} return (A) this;
  }
  public java.lang.Boolean hasAdditionalProperties() {
    return this.additionalProperties != null;
  }
  public boolean equals(java.lang.Object o) {
    if (this == o) return true;
    if (o == null || getClass() != o.getClass()) return false;
    ObjectMetricStatusFluentImpl that = (ObjectMetricStatusFluentImpl) o;
    if (current != null ? !current.equals(that.current) :that.current != null) return false;
    if (describedObject != null ? !describedObject.equals(that.describedObject) :that.describedObject != null) return false;
    if (metric != null ? !metric.equals(that.metric) :that.metric != null) return false;
    if (additionalProperties != null ? !additionalProperties.equals(that.additionalProperties) :that.additionalProperties != null) return false;
    return true;
  }
  public int hashCode() {
    return java.util.Objects.hash(current,  describedObject,  metric,  additionalProperties,  super.hashCode());
  }
  public class CurrentNestedImpl<N> extends io.fabric8.kubernetes.api.model.autoscaling.v2beta2.MetricValueStatusFluentImpl<io.fabric8.kubernetes.api.model.autoscaling.v2beta2.ObjectMetricStatusFluent.CurrentNested<N>> implements io.fabric8.kubernetes.api.model.autoscaling.v2beta2.ObjectMetricStatusFluent.CurrentNested<N>,io.fabric8.kubernetes.api.builder.Nested<N>{
    CurrentNestedImpl(io.fabric8.kubernetes.api.model.autoscaling.v2beta2.MetricValueStatus item) {
      this.builder = new io.fabric8.kubernetes.api.model.autoscaling.v2beta2.MetricValueStatusBuilder(this, item);
    }
    CurrentNestedImpl() {
      this.builder = new io.fabric8.kubernetes.api.model.autoscaling.v2beta2.MetricValueStatusBuilder(this);
    }
    io.fabric8.kubernetes.api.model.autoscaling.v2beta2.MetricValueStatusBuilder builder;
    public N and() {
      return (N) ObjectMetricStatusFluentImpl.this.withCurrent(builder.build());
    }
    public N endCurrent() {
      return and();
    }
    
  }
  public class DescribedObjectNestedImpl<N> extends io.fabric8.kubernetes.api.model.autoscaling.v2beta2.CrossVersionObjectReferenceFluentImpl<io.fabric8.kubernetes.api.model.autoscaling.v2beta2.ObjectMetricStatusFluent.DescribedObjectNested<N>> implements io.fabric8.kubernetes.api.model.autoscaling.v2beta2.ObjectMetricStatusFluent.DescribedObjectNested<N>,io.fabric8.kubernetes.api.builder.Nested<N>{
    DescribedObjectNestedImpl(io.fabric8.kubernetes.api.model.autoscaling.v2beta2.CrossVersionObjectReference item) {
      this.builder = new io.fabric8.kubernetes.api.model.autoscaling.v2beta2.CrossVersionObjectReferenceBuilder(this, item);
    }
    DescribedObjectNestedImpl() {
      this.builder = new io.fabric8.kubernetes.api.model.autoscaling.v2beta2.CrossVersionObjectReferenceBuilder(this);
    }
    io.fabric8.kubernetes.api.model.autoscaling.v2beta2.CrossVersionObjectReferenceBuilder builder;
    public N and() {
      return (N) ObjectMetricStatusFluentImpl.this.withDescribedObject(builder.build());
    }
    public N endDescribedObject() {
      return and();
    }
    
  }
  public class MetricNestedImpl<N> extends io.fabric8.kubernetes.api.model.autoscaling.v2beta2.MetricIdentifierFluentImpl<io.fabric8.kubernetes.api.model.autoscaling.v2beta2.ObjectMetricStatusFluent.MetricNested<N>> implements io.fabric8.kubernetes.api.model.autoscaling.v2beta2.ObjectMetricStatusFluent.MetricNested<N>,io.fabric8.kubernetes.api.builder.Nested<N>{
    MetricNestedImpl(io.fabric8.kubernetes.api.model.autoscaling.v2beta2.MetricIdentifier item) {
      this.builder = new io.fabric8.kubernetes.api.model.autoscaling.v2beta2.MetricIdentifierBuilder(this, item);
    }
    MetricNestedImpl() {
      this.builder = new io.fabric8.kubernetes.api.model.autoscaling.v2beta2.MetricIdentifierBuilder(this);
    }
    io.fabric8.kubernetes.api.model.autoscaling.v2beta2.MetricIdentifierBuilder builder;
    public N and() {
      return (N) ObjectMetricStatusFluentImpl.this.withMetric(builder.build());
    }
    public N endMetric() {
      return and();
    }
    
  }
  
}
